@@ -7,15 +7,25 @@ from .update import UpdateHandler
 
 class MessageHandler(UpdateHandler):
     filters: ext.filters.BaseFilter = ext.filters.UpdateType.MESSAGE
-    reply_text: str | None = None
     reply_markup: ReplyMarkup | None = None
 
+    def __init__(self, reply_text: str | None = None) -> None:
+        self.reply_text = reply_text
+        super().__init__()
+
     def build(self) -> PTBHandler:
         return ext.MessageHandler(self.filters, self.handle)
 
     async def callback(self) -> None:
-        text = self.get_validated_field("reply_text", self.reply_text)
-        await self.reply(text, self.reply_markup)
+        text = self.get_reply_text()
+        markup = self.get_reply_markup()
+        await self.reply(text, markup)
+
+    def get_reply_text(self) -> str:
+        return self.get_validated_field("reply_text", self.reply_text)
+
+    def get_reply_markup(self) -> ReplyMarkup | None:
+        return self.reply_markup
 
     async def reply(
         self,
